@@ -3,7 +3,4 @@ from .event import PluginEvent
 from .event import UnplugEvent
 from .event import RecomputeEvent
 from .event_queue import EventQueue
-
-del event
-del event_queue
-
+from .acndata_events import *
